@@ -53,11 +53,14 @@ def entity_dataclass(class_: type = None, *, entity_name: str = None, **kwargs):
 
 @functools.cache
 def prepare_entity_column_names(entity_type: Type[Entity], prefix: str = '') -> list[str]:
+    if not is_entity_dataclass(entity_type):
+        raise TypeError("expected entity_dataclass")
+
     result = []
     for field in fields(entity_type):
         type_origin = getattr(field.type, '__origin__', None)
         type_args = getattr(field.type, '__args__', None)
-        if isinstance(type_origin, type) and dataclasses.is_dataclass(type_args[0]):
+        if isinstance(type_origin, type) and is_entity_dataclass(type_args[0]):
             result += prepare_entity_column_names(type_args[0], field.name + RELATIONSHIP_COLUMN_SEPARATOR)
         else:
             result.append(prefix + field.name)
